add_new_datasource adds a new data source to one of the ligand-receptor, signaling and gene regulatory data sources.
Arguments
- new_source
A data frame / tibble containing novel interactions of the ligand-receptor, signaling or gene regulatory layer (required columns: from, to, source)
- network
NULL or a data frame / tibble containing the base network to which you want to add the new data source (required columns: from, to, source)
- new_weight
a weight value between 0 and 1 to assign to your new data source
- source_weights_df
A data frame / tibble containing the weights associated to each already included individual data source (required columns: source, weight).