Annotation table of all data sources used in the NicheNet model
Source:R/data.R
annotation_data_sources.RdA data.frame/tibble describing for each type of data source the "parent" database and type of interactions it countains.
R/data.R
annotation_data_sources.RdA data.frame/tibble describing for each type of data source the "parent" database and type of interactions it countains.