Skip to contents

calculate_fraction_top_predicted Defines the fraction of genes belonging to the geneset or background and to the top-predicted genes.

Usage

calculate_fraction_top_predicted(affected_gene_predictions, quantile_cutoff = 0.95)

Arguments

affected_gene_predictions

Tibble with columns "gene", "prediction" and "response" (e.g. output of function `assess_rf_class_probabilities`)

quantile_cutoff

Quantile of which genes should be considered as top-predicted targets. Default: 0.95, thus considering the top 5 percent predicted genes as predicted targets.

Value

A tibble indicating the number of genes belonging to the gene set of interest or background (true_target column), the number and fraction of genes of these gruops that were part of the top predicted targets in a specific cross-validation round.