Assess how well classification predictions accord to the expected response
Source:R/application_prediction.R
classification_evaluation_continuous_pred_wrapper.Rdclassification_evaluation_continuous_pred_wrapper Assess how well classification predictions accord to the expected response.
Examples
if (FALSE) { # \dontrun{
weighted_networks <- construct_weighted_networks(lr_network, sig_network, gr_network, source_weights_df)
ligands <- list("TNF", "BMP2", "IL4")
ligand_target_matrix <- construct_ligand_target_matrix(weighted_networks, lr_network, ligands, ltf_cutoff = 0, algorithm = "PPR", damping_factor = 0.5, secondary_targets = FALSE)
potential_ligands <- c("TNF", "BMP2", "IL4")
geneset <- c("SOCS2", "SOCS3", "IRF1")
background_expressed_genes <- c("SOCS2", "SOCS3", "IRF1", "ICAM1", "ID1", "ID2", "ID3")
fold1_rf_prob <- assess_rf_class_probabilities(round = 1, folds = 2, geneset = geneset, background_expressed_genes = background_expressed_genes, ligands_oi = potential_ligands, ligand_target_matrix = ligand_target_matrix)
classification_evaluation_continuous_pred_wrapper(fold1_rf_prob)
} # }