construct_tf_target_matrix Convert integrated gene regulatory weighted network into matrix format.
Arguments
- weighted_networks
A list of two elements: lr_sig: a data frame/ tibble containg weighted ligand-receptor and signaling interactions (from, to, weight); and gr: a data frame/tibble containng weighted gene regulatory interactions (from, to, weight)
- tfs_as_cols
Indicate whether ligands should be in columns of the matrix and target genes in rows or vice versa. Default: FALSE
- standalone_output
Indicate whether the ligand-tf matrix should be formatted in a way convenient to use alone (with gene symbols as row/colnames). Default: FALSE
Examples
if (FALSE) { # \dontrun{
## Generate the ligand-target matrix from loaded weighted_networks
weighted_networks <- construct_weighted_networks(lr_network, sig_network, gr_network, source_weights_df)
tf_target <- construct_tf_target_matrix(weighted_networks, tfs_as_cols = TRUE, standalone_output = TRUE)
} # }