Construct weighted layer-specific networks
Source:R/construct_ligand_to_target.R
construct_weighted_networks.Rdconstruct_weighted_networks construct layer-specific weighted integrated networks from input source networks via weighted aggregation.
Usage
construct_weighted_networks(lr_network, sig_network, gr_network,source_weights_df, n_output_networks = 2)Arguments
- lr_network
A data frame / tibble containing ligand-receptor interactions (required columns: from, to, source)
- sig_network
A data frame / tibble containing signaling interactions (required columns: from, to, source)
- gr_network
A data frame / tibble containing gene regulatory interactions (required columns: from, to, source)
- source_weights_df
A data frame / tibble containing the weights associated to each individual data source. Sources with higher weights will contribute more to the final model performance (required columns: source, weight). Note that only interactions described by sources included here, will be retained during model construction.
- n_output_networks
The number of output networks to return: 2 (ligand-signaling and gene regulatory; default) or 3 (ligand-receptor, signaling and gene regulatory).