Convert cluster assignment to settings format suitable for target gene prediction.
Source:R/application_prediction.R
convert_cluster_to_settings.Rdconvert_cluster_to_settings Convert cluster assignment to settings format suitable for target gene prediction.
Arguments
- i
The cluster number of the cluster of interest to which genes should belong
- cluster_vector
Named vector containing the cluster number to which every gene belongs
- setting_name
Base name of the setting
- setting_from
Active ligands for the specific setting
- background
NULL or a character vector of genes belonging to the background. When NULL: the background will be formed by genes belonging to other clusters that the cluster of interest. Default NULL. If not NULL and genes present in the cluster of interest are in this vector of background gene names, these genes will be removed from the background.