Convert expression settings to correct settings format for evaluation of target gene prediction.
Source:R/evaluate_model_target_prediction.R
convert_expression_settings_evaluation.Rdconvert_expression_settings_evaluation Converts expression settings to correct settings format for evaluation of target gene prediction.
Value
A list with following elements: $name, $from, $response. $response will be a gene-named logical vector indicating whether the gene's transcription was influenced by the active ligand(s) in the setting of interest.
Examples
if (FALSE) { # \dontrun{
settings <- lapply(expression_settings_validation, convert_expression_settings_evaluation)
} # }