Convert human gene symbols to their mouse one-to-one orthologs.
Source:R/supporting_functions.R
convert_human_to_mouse_symbols.Rdconvert_human_to_mouse_symbols Convert human gene symbols to their mouse one-to-one orthologs.
R/supporting_functions.R
convert_human_to_mouse_symbols.Rdconvert_human_to_mouse_symbols Convert human gene symbols to their mouse one-to-one orthologs.