Skip to contents

convert_mouse_to_human_symbols Convert mouse gene symbols to their human one-to-one orthologs.

Usage

convert_mouse_to_human_symbols(symbols, version = 1)

Arguments

symbols

A character vector of official mouse gene symbols

version

Indicates which version of the mouse-human annotations should be used: Default 1. In April 2022, and nichenetr 2.0., the default will change to 2.

Value

A character vector of official human gene symbols (one-to-one orthologs of the input mouse gene symbols).

Examples

library(dplyr)
mouse_symbols <- c("Tnf", "Ifng")
human_symbols <- mouse_symbols %>% convert_mouse_to_human_symbols()