Skip to contents

A data.frame/tibble describing HGNC human gene symbols, their entrez ids and the MGI mouse gene symbols and entrez ids of the one-one orthologs as determined via NCBI's homologene db and biomaRt ensembl db.

Usage

geneinfo_2022

Format

A data frame/tibble

symbol

human gene symbol

entrez

human gene entrez

entrez_mouse

mouse homolog gene entrez

symbol_mouse

mouse homolog gene symbol