Generate tables used for generate_prioritization_tables
Source: R/prioritization.R
generate_info_tables.RdCalculate differential expression, average expression, and condition specificity of ligands and receptors.
Usage
generate_info_tables(
seuratObj,
celltype_colname,
senders_oi,
receivers_oi,
lr_network_filtered,
condition_colname = NULL,
condition_oi = NULL,
condition_reference = NULL,
scenario = "case_control",
assay_oi = NULL,
...
)Arguments
- seuratObj
Seurat object
- celltype_colname
Name of the meta data column that indicates the cell type of a cell
- senders_oi
Default NULL: all celltypes will be considered as senders. If you want to select specific senders of interest: you can add this here as character vector.
- receivers_oi
Default NULL: all celltypes will be considered as receivers If you want to select specific receivers of interest: you can add this here as character vector.
- lr_network_filtered
Ligand-receptor network that has been filtered to only contain ligands and receptors that are expressed
- condition_colname
Name of the meta data column that indicates from which group/condition a cell comes from
- condition_oi
If provided, subset seurat_obj so DE is only calculated for cells belonging to condition_oi
- condition_reference
Reference condition for condition specificity calculation
- scenario
"case_control" or "one_condition": if "case_control", calculate condition specificity. If "one_condition", only calculate cell type specificity.
- assay_oi
Which assay need to be used for DE calculation. If NULL, will use
DefaultAssay- ...
Arguments passed to
FindAllMarkers,FindMarkers, andAverageExpression