Get active gene regulatory network in a receiver cell.
Source:R/application_network_extraction.R
get_active_regulatory_network.Rdget_active_regulatory_network Get active regulatory network by looking for which TFs/regulatory genes are expressed in the receiver cell. Instead of looking at absolute expression, it is possible as well to extract a gene regulatory network of differentially expressed TFs if a vector of log2 fold change values is used as input.
Usage
get_active_regulatory_network(expression_receiver, gr_network, expression_cutoff_receiver = 0)Arguments
- expression_receiver
A named numeric vector of gene expression levels (absolute or logfc) for the receiver cell that receives extracellular signals from the sender cell
- gr_network
A data frame / tibble containing gene regulatory interactions (required columns: from, to). Can be both unweighted and weighted.
- expression_cutoff_receiver
The cutoff on expression value for the receiver cell: receptors will be considered active if their expression is higher than the cutoff. Default: 0.
Value
A data frame containing at least the variables from, to, receiver_expression. In this network, the active gene regulatory interactions in the system of interest are shown.
Examples
if (FALSE) { # \dontrun{
library(dplyr)
expression_vector_receiver <- rnorm(n = 10000, mean = 6, sd = 3)
names(expression_vector_receiver) <- sample(x = geneinfo_human$symbol, size = 10000, replace = FALSE)
receiver_gr_network <- get_active_regulatory_network(expression_vector_receiver, gr_network, expression_cutoff_receiver = 4)
} # }