Skip to contents

get_ncitations_genes: Get the number of times of gene is mentioned in the pubmed literature

Usage

get_ncitations_genes(file = "ftp://ftp.ncbi.nih.gov/gene/DATA/gene2pubmed.gz")

Arguments

file

A file containing a data frame denoting the pubmed ids in which a particular gene entrez of a particulat species is mentioned (variables: taxid, entrez, pubmedid). Default = "ftp://ftp.ncbi.nih.gov/gene/DATA/gene2pubmed.gz"

Value

A data.frame with following variables: entrez, ncitations, symbol,entrez_mouse, symbol_mouse

Examples

if (FALSE) { # \dontrun{
ncitations <- get_ncitations_genes(file = "ftp://ftp.ncbi.nih.gov/gene/DATA/gene2pubmed.gz")
} # }