Skip to contents

get_weighted_ligand_receptor_links Get the weighted ligand-receptor links between a possible ligand and its receptors

Usage

get_weighted_ligand_receptor_links(
  best_upstream_ligands,
  expressed_receptors,
  lr_network,
  weighted_networks_lr_sig
)

Arguments

best_upstream_ligands

Character vector containing ligands of interest.

expressed_receptors

Character vector of receptors expressed in the cell type of interest.

lr_network

A data frame with two columns, from and to, containing the ligand-receptor interactions.

weighted_networks_lr_sig

A data frame with three columns, from, to and weight, containing the ligand-receptor interactions and their weights.

Examples

if (FALSE) { # \dontrun{
ligand_receptor_links_df <- get_weighted_ligand_receptor_links(best_upstream_ligands, expressed_receptors, lr_network, weighted_networks$lr_sig)
} # }