make_ligand_activity_target_exprs_plot
Source:R/differential_nichenet_plotting.R
make_ligand_activity_target_exprs_plot.Rdmake_ligand_activity_target_exprs_plot Plot the ligand expression in senders plus their activity and target genes in receivers
Usage
make_ligand_activity_target_exprs_plot(receiver_oi, prioritized_tbl_oi, prioritization_tbl_ligand_receptor, prioritization_tbl_ligand_target,
exprs_tbl_ligand, exprs_tbl_target, lfc_cutoff, ligand_target_matrix, scaled_ligand_activity_limits = "abs_max", plot_legend = TRUE, heights = NULL, widths = NULL)Arguments
- receiver_oi
Name of the receiver cell type of interest
- prioritized_tbl_oi
Dataframe with the ligand-receptor interactions that should be visualized
- prioritization_tbl_ligand_receptor
$prioritization_tbl_ligand_receptor slot of `get_prioritization_tables`
- prioritization_tbl_ligand_target
$prioritization_tbl_ligand_target slot of `get_prioritization_tables`
- exprs_tbl_ligand
Dataframe with the expression values for the ligands in the sender cell types
- exprs_tbl_target
Dataframe with the expression values for the targets in the receiver cell types
- lfc_cutoff
Cutoff used on the logFC value
- ligand_target_matrix
ligand-target matrix
- scaled_ligand_activity_limits
limits used in the heatmap for the scaled ligand activity, one of "abs_max" (-+ absolute maximum), "min_max" (minimum and maximum), or "IQR" (cf. boxplot, outliers are squished to the limits)
- plot_legend
TRUE (default): add legend to the plot. FALSE: do not add legend.
- heights
automatic determination if default NULL. If not NULL: number given by the user to indicate the requested heights, which are the height proportions of the different row panels in the plot.
- widths
automatic determination if default NULL. If not NULL: number given by the user to indicate the requested widths, which are the width proportions of the different columns (side-by-side heatmaps) in the plot.
Examples
if (FALSE) { # \dontrun{
make_ligand_activity_target_exprs_plot(receiver_oi, prioritized_tbl_oi, prioritization_tbl_ligand_receptor, prioritization_tbl_ligand_target, exprs_tbl_ligand, exprs_tbl_target, lfc_cutoff, ligand_target_matrix, scaled_ligand_activity_limits = "abs_max", plot_legend = TRUE, heights = NULL, widths = NULL)
} # }