make_ligand_receptor_lfc_plot
Source:R/differential_nichenet_plotting.R
make_ligand_receptor_lfc_plot.Rdmake_ligand_receptor_lfc_plot Plot the ligand logFC in senders plus the logFC of their receptors in the receivers.
Usage
make_ligand_receptor_lfc_plot(receiver_oi, prioritized_tbl_oi, prioritization_tbl_ligand_receptor, plot_legend = TRUE, heights = NULL, widths = NULL)Arguments
- receiver_oi
Name of the receiver cell type of interest
- prioritized_tbl_oi
Dataframe with the ligand-receptor interactions that should be visualized
- prioritization_tbl_ligand_receptor
$prioritization_tbl_ligand_receptor slot of `get_prioritization_tables`
- plot_legend
TRUE (default): add legend to the plot. FALSE: do not add legend.
- heights
automatic determination if default NULL. If not NULL: number given by the user to indicate the requested heights, which are the height proportions of the different row panels in the plot.
- widths
automatic determination if default NULL. If not NULL: number given by the user to indicate the requested widths, which are the width proportions of the different columns (side-by-side heatmaps) in the plot.