Skip to contents

Make a line plot comparing the ranking of ligands based on their activities in the sender-agnostic and sender-focused approaches

Usage

make_line_plot(ligand_activities, potential_ligands, ranking_range = c(1, 20), agnostic_color = "tomato", focused_color = "black", tied_color = "gray75", inset_scale = 1)

Arguments

ligand_activities

Dataframe containing the ligand activities from the sender-agnostic approach

potential_ligands

Character vector containing the ligands that are expressed in the sender cell type (i.e. the ligands that are used in the sender-focused approach)

ranking_range

Numeric vector of length 2 indicating the range of the rankings to be displayed (default: c(1, 20))

agnostic_color

Color representing ligands only inthe sender-agnostic approach (default: "tomato")

focused_color

Color representing expressed ligands from the sender-focused approach (default: "black")

tied_color

Color to shade ligands that are tied in the same rank (default: "gray75")

inset_scale

Numeric value indicating the size of the points and text in the inset (default: 1)

label_size

Numeric value indicating size of the data labels, before scaling (default: 3.88, same as older versions, but now explicitly settable)

point_size

Numeric value indicating size of the data points, before scaling (default: 1.5, same as older versions, but now explicitly settable)

line_width

Numeric value indicating size of the line width, before scaling (default: 0.5, same as older versions, but now explicitly settable)

Value

A ggplot object showing the distribution of sender-focused ligands, as well as a line plot inset comparing the rankings between the two approaches

Examples

if (FALSE) { # \dontrun{
# Default
make_line_plot(ligand_activities, potential_ligands)
} # }