Prepare settings for leave-one-out characterization
Source:R/characterization_data_sources.R
prepare_settings_leave_one_out_characterization.Rdprepare_settings_leave_one_out_characterization will generate a list of lists containing the data source weights that need to be used for model construction. Every sub-list will contain the data source weights needed to make so called leave-one-out models in one ligand-signaling data source is or gene regulatory data source is left out.
Usage
prepare_settings_leave_one_out_characterization(lr_network, sig_network, gr_network, source_weights_df)Arguments
- lr_network
A data frame / tibble containing ligand-receptor interactions (required columns: from, to, source)
- sig_network
A data frame / tibble containing signaling interactions (required columns: from, to, source)
- gr_network
A data frame / tibble containing gene regulatory interactions (required columns: from, to, source)
- source_weights_df
A data frame / tibble containing the weights associated to each individual data source. Sources with higher weights will contribute more to the final model performance (required columns: source, weight). Note that only interactions described by sources included here, will be retained during model construction.