Prepare settings for one-vs-one characterization
Source:R/characterization_data_sources.R
prepare_settings_one_vs_one_characterization.Rdprepare_settings_one_vs_one_characterization will generate a list of lists containing the data source weights that need to be used for model construction. Every sub-list will contain the data source weights needed to make so called one-vs-one models in which only one ligand-signaling data source and only one gene regulatory data source is used. It is also possible to construct one-vs-one-vs-one models by keeping 1 ligand-receptor, 1 signaling and 1 gene regulatory data source.
Usage
prepare_settings_one_vs_one_characterization(lr_network, sig_network, gr_network, lr_network_separate = FALSE)Arguments
- lr_network
A data frame / tibble containing ligand-receptor interactions (required columns: from, to, source)
- sig_network
A data frame / tibble containing signaling interactions (required columns: from, to, source)
- gr_network
A data frame / tibble containing gene regulatory interactions (required columns: from, to, source)
- lr_network_separate
Indicate whether the one-vs-one models should contain 1 ligand-receptor, 1 signaling and 1 gene regulatory network source (TRUE) or just 1 ligand-signaling combined and 1 gene regulatory source (FALSE). Default: FALSE.
Value
A list of lists. Every sub-list contains following elements: $model_name; $source_lr_sig: the name of the left-in ligand-signaling data source (or $source_lr and $source_sig if lr_network_separate is TRUE); $source_gr: the name of the left-in gene regulatory data source and $source_weights: named numeric vector containing the data source weights that will be used for the construction of one-vs-one models.