Skip to contents

randomize_complete_network_source_specific Randomizes an integrated network of interest by edge swapping in the source-specific networks to preserve the degree of the nodes

Usage

randomize_complete_network_source_specific(network)

Arguments

network

A data frame / tibble containing gene-gene interactions (required columns: $from, $to, $source)

Value

A randomized network ($from, $to, $source).

Examples

if (FALSE) { # \dontrun{
random_lr <- randomize_complete_network_source_specific(lr_network)
} # }