Skip to contents

randomize_datasource_network Randomizes a network of a data source of interest by edge swapping to preserve the degree of the nodes.

Usage

randomize_datasource_network(datasource, network)

Arguments

datasource

The name of the data source for which the interactions need to be shuffled.

network

A data frame / tibble containing gene-gene interactions (required columns: $from, $to, $source)

Value

A randomized network ($from, $to, $source)

Examples

if (FALSE) { # \dontrun{
datasource_lr <- lr_network$source[1]
lr_randomized_source <- randomize_datasource_network(datasource_lr, lr_network)
} # }