Skip to contents

randomize_network Randomizes a network of interest by edge swapping to preserve the degree of the nodes

Usage

randomize_network(network,output_weighted = FALSE)

Arguments

network

A data frame / tibble containing gene-gene interactions (required columns: $from, $to)

output_weighted

Indicate whether the output network should be made weighted by assigning a weight of 1 to each interaction.

Value

A randomized network ($from, $to; and $weight = 1 if output_weighted == TRUE).

Examples

if (FALSE) { # \dontrun{
random_lr <- randomize_network(lr_network)
} # }