Normalize values in a vector by quantile scaling and add a pseudovalue of 0.001
Source:R/differential_nichenet.R
scale_quantile_adapted.Rdscale_quantile_adapted Normalize values in a vector by quantile scaling. Add a pseudovalue of 0.001 to avoid having a score of 0 for the lowest value.
Examples
if (FALSE) { # \dontrun{
scale_quantile_adapted(rnorm(5))
} # }