A data.frame/tibble describing weight associated to each data source. These weights will be used for weighted aggregagion of source networks
A data.frame/tibble describing weight associated to each data source. These weights will be used for weighted aggregagion of source networks