alias_to_symbol_seurat Convert aliases to official gene symbols in a Seurat Object. Makes use of `convert_alias_to_symbols`
Usage
alias_to_symbol_seurat(seurat_obj, organism)
Arguments
- seurat_obj
Seurat object, v4 or below. For Seurat v5, a warning is thrown and the same object will be returned.
- organism
Is Seurat object data from "mouse" or "human"
Examples
if (FALSE) { # \dontrun{
seurat_object_lite <- readRDS(url("https://zenodo.org/record/3531889/files/seuratObj_test.rds"))
seurat_object_lite <- seurat_object_lite %>% alias_to_symbol_seurat("human")
} # }