Determine the fraction of genes belonging to the geneset or background and to the top-predicted genes.
Source:R/application_prediction.R
calculate_fraction_top_predicted.Rdcalculate_fraction_top_predicted Defines the fraction of genes belonging to the geneset or background and to the top-predicted genes.
Arguments
- affected_gene_predictions
Tibble with columns "gene", "prediction" and "response" (e.g. output of function `assess_rf_class_probabilities`)
- quantile_cutoff
Quantile of which genes should be considered as top-predicted targets. Default: 0.95, thus considering the top 5 percent predicted genes as predicted targets.