Convert mouse gene symbols to their human one-to-one orthologs.
Source:R/supporting_functions.R
convert_mouse_to_human_symbols.Rdconvert_mouse_to_human_symbols Convert mouse gene symbols to their human one-to-one orthologs.
R/supporting_functions.R
convert_mouse_to_human_symbols.Rdconvert_mouse_to_human_symbols Convert mouse gene symbols to their human one-to-one orthologs.