Get the number of times of gene is mentioned in the pubmed literature
Source:R/calculate_popularity_bias.R
get_ncitations_genes.Rdget_ncitations_genes: Get the number of times of gene is mentioned in the pubmed literature
R/calculate_popularity_bias.R
get_ncitations_genes.Rdget_ncitations_genes: Get the number of times of gene is mentioned in the pubmed literature