Get the weighted ligand-receptor links between a possible ligand and its receptors
Source:R/application_prediction.R
get_weighted_ligand_receptor_links.Rdget_weighted_ligand_receptor_links Get the weighted ligand-receptor links between a possible ligand and its receptors
Usage
get_weighted_ligand_receptor_links(
best_upstream_ligands,
expressed_receptors,
lr_network,
weighted_networks_lr_sig
)Arguments
- best_upstream_ligands
Character vector containing ligands of interest.
- expressed_receptors
Character vector of receptors expressed in the cell type of interest.
- lr_network
A data frame with two columns,
fromandto, containing the ligand-receptor interactions.- weighted_networks_lr_sig
A data frame with three columns,
from,toandweight, containing the ligand-receptor interactions and their weights.