make_circos_lr Plot the prioritized ligand-receptor pairs in a circos plot (via the circlize package)
Usage
make_circos_lr(
prioritized_tbl_oi,
colors_sender,
colors_receiver,
cutoff = 0,
scale = FALSE,
transparency = NULL,
circos_type = "normal",
border = TRUE,
separate_legend = FALSE
)Arguments
- prioritized_tbl_oi
Dataframe with the ligand-receptor interactions that should be visualized
- colors_sender
Named character vector giving the colors of each sender cell type
- colors_receiver
Named character vector giving the colors of each receiver cell type
- cutoff
Threshold On the prioritization score - if lower than this value, the link will be removed – default = 0.
- scale
scale value in `chordDiagram`. Default: FALSE
- transparency
Vector of transparency values of the links or NULL, in that case this will be calculated automatically. Default: NULL.
- circos_type
"normal" or "arrow". Default: "normal".
- border
Border to arrows or not in `chordDiagram`? (Default: TRUE)
- separate_legend
return plot and legend as separate objects? (Default: FALSE)