Draw a circos plot
Usage
make_circos_plot(vis_circos_obj, transparency = FALSE, args.circos.text = list(), ...)Arguments
- vis_circos_obj
Object returned by
prepare_circos_visualization- transparency
Logical indicating whether the transparency of the links will correspond to the ligand-target potential score (default: FALSE)
- args.circos.text
List of arguments to pass to
circos.text(by default, the text size is set to 1)- ...
Additional arguments to pass to
chordDiagram
Examples
if (FALSE) { # \dontrun{
# Default
make_circos_plot(vis_circos_obj, transparency = FALSE)
# Transparency
make_circos_plot(vis_circos_obj, transparency = TRUE)
# Make text smaller
make_circos_plot(vis_circos_obj, transparency = TRUE, args.circos.text = list(cex = 0.5))
# Don't sort links of each ligand based on widths (not recommended)
make_circos_plot(vis_circos_obj, transparency = TRUE, args.circos.text = list(cex = 0.5), link.sort = FALSE)
} # }