Make a ggplot heatmap object from an input ligand-target matrix.
Source:R/application_visualization.R
make_heatmap_bidir_lt_ggplot.Rdmake_heatmap_bidir_lt_ggplot Make a ggplot heatmap object from an input ligand-target matrix in which it is indicated whether a gene is a top target of a ligand ("top-target"), the ligand is a top ligand of the gene ("top-ligand") or both ("top") or none ("none").
Usage
make_heatmap_bidir_lt_ggplot(matrix, y_name, x_name, y_axis = TRUE, x_axis = TRUE, x_axis_position = "top", legend_position = "top", ...)
#'Arguments
- matrix
Matrix with continuous values to plot in heatmap
- y_name
Title of the y-axis
- x_name
Title of the x-axis
- y_axis
Should y-axis label names and titles be displayed? TRUE or FALSE. Default: TRUE.
- x_axis
Should x-axis label names and titles be displayed? TRUE or FALSE. Default: TRUE.
- x_axis_position
X-axis position: "top" or "bottomm"; only relevant if x_axis == TRUE. Default:"top".
- legend_position
Legend position: "top", "bottom", "left", "right" or "none". Default: "top"
- ...
Optional arguments passed to element_text(); used to set font type and size of axis labels and titles.