Randomize an integrated network by shuffling its source networks
Source:R/construct_random_networks.R
randomize_complete_network_source_specific.Rdrandomize_complete_network_source_specific Randomizes an integrated network of interest by edge swapping in the source-specific networks to preserve the degree of the nodes