Cut off outer quantiles and rescale to a [0, 1] range
Source:R/application_prediction.R
scale_quantile.Rdscale_quantile Cut off outer quantiles and rescale to a [0, 1] range
Value
The centered, scaled matrix or vector. The numeric centering and scalings used are returned as attributes.
Examples
if (FALSE) { # \dontrun{
## Generate a matrix from a normal distribution
## with a large standard deviation, centered at c(5, 5)
x <- matrix(rnorm(200 * 2, sd = 10, mean = 5), ncol = 2)
## Scale the dataset between [0,1]
x_scaled <- scale_quantile(x)
## Show ranges of each column
apply(x_scaled, 2, range)
} # }