Visualize parameter values from the output of run_nsga2R_cluster.
Source: R/parameter_optimization.R
visualize_parameter_values.Rdvisualize_parameter_values will take as input the output of run_nsga2R_cluster and visualize the data source weights and hyperparameters of the best and worst solutions
Usage
visualize_parameter_values(result_nsga2r, source_names, top_ns = c(5, 10, -10, -25))Value
A list containing two ggplot objects, one for the data source weights and one for the hyperparameters.
Examples
if (FALSE) { # \dontrun{
results <- run_nsga2R_cluster(model_evaluation_optimization_nsga2r,
varNo = n_param, objDim = n_obj,
lowerBounds = lower_bounds, upperBounds = upper_bounds, popSize = 360, tourSize = 2, generations = 15, ncores = 8
)
# Visualize the best and worst 5 solutions
visualize_parameter_values(results, source_names, top_ns = c(5, -5))
} # }